@@ -336,8 +336,8 @@ def check_args():
             eprint(" |-- in case of duplicate ids, the last entry in ff will be extracted")
         elif args.duplicates:
             eprint(" |-- in case of duplicate ids, all entries in ff will be extracted")
-            if args.list_blocksize is not None:
-                eprint("    => NOTICE: -b not recommended if many entries with same identifier requested")
+            if not args.merged and (args.list_blocksize is None or args.list_blocksize != 0):
+                eprint("    => NOTICE: if many entries with same identifier requested consider using -b 0 or -m")
 
     if args.flatfile[-3:] == ".gz" and not args.compressed:
         eprint("    => NOTICE: -f argument has extension .gz: assuming flatfile is compressed")
